# Changelog

## [Unreleased](https://github.com/dermatologist/crisp-t/tree/HEAD)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v2.3.0...HEAD)

**Closed issues:**

- Add additional models to crisp-ui \(Web UI - NEW!\) [\#92](https://github.com/dermatologist/crisp-t/issues/92)
- Build a UI for CRISP package that uses the new COPILOT-SDK to interact with CRISP using CLI and display results. [\#86](https://github.com/dermatologist/crisp-t/issues/86)

## [v2.3.0](https://github.com/dermatologist/crisp-t/tree/v2.3.0) (2026-02-11)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v2.2.1...v2.3.0)

## [v2.2.1](https://github.com/dermatologist/crisp-t/tree/v2.2.1) (2026-02-01)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v2.2.0...v2.2.1)

**Closed issues:**

- Refactor mcp/server.py by modularizing tools into separate files and organizing prompt templates. [\#79](https://github.com/dermatologist/crisp-t/issues/79)
- Feature request: Support multiple text columns while importing documents from CSV. [\#77](https://github.com/dermatologist/crisp-t/issues/77)
- Add time‑based analysis to CRISP-T [\#66](https://github.com/dermatologist/crisp-t/issues/66)

## [v2.2.0](https://github.com/dermatologist/crisp-t/tree/v2.2.0) (2026-01-31)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v2.1.0...v2.2.0)

## [v2.1.0](https://github.com/dermatologist/crisp-t/tree/v2.1.0) (2026-01-30)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v2.0.0...v2.1.0)

## [v2.0.0](https://github.com/dermatologist/crisp-t/tree/v2.0.0) (2026-01-29)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.2.3...v2.0.0)

## [v1.2.3](https://github.com/dermatologist/crisp-t/tree/v1.2.3) (2026-01-09)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.2.2...v1.2.3)

**Closed issues:**

- Feature request: Improve the CLI scripts using click. [\#60](https://github.com/dermatologist/crisp-t/issues/60)
- Feature request: Improve the cli with Typer. [\#57](https://github.com/dermatologist/crisp-t/issues/57)

## [v1.2.2](https://github.com/dermatologist/crisp-t/tree/v1.2.2) (2025-12-23)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.2.1...v1.2.2)

## [v1.2.1](https://github.com/dermatologist/crisp-t/tree/v1.2.1) (2025-12-01)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.2.0...v1.2.1)

## [v1.2.0](https://github.com/dermatologist/crisp-t/tree/v1.2.0) (2025-11-08)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.1.1...v1.2.0)

**Implemented enhancements:**

- Feature Request: Add a graph creation and visualization feature. [\#49](https://github.com/dermatologist/crisp-t/issues/49)

## [v1.1.1](https://github.com/dermatologist/crisp-t/tree/v1.1.1) (2025-10-28)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.1.0...v1.1.1)

## [v1.1.0](https://github.com/dermatologist/crisp-t/tree/v1.1.0) (2025-10-28)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v1.0.0...v1.1.0)

## [v1.0.0](https://github.com/dermatologist/crisp-t/tree/v1.0.0) (2025-10-26)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.9.0...v1.0.0)

**Implemented enhancements:**

- Feature request: Improve the --print command with more options and better display. [\#45](https://github.com/dermatologist/crisp-t/issues/45)

## [v0.9.0](https://github.com/dermatologist/crisp-t/tree/v0.9.0) (2025-10-25)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.8.0...v0.9.0)

**Implemented enhancements:**

- Feature Request: Implement Topological Data Analysis Ball Mapper \(TDABM\) [\#42](https://github.com/dermatologist/crisp-t/issues/42)

## [v0.8.0](https://github.com/dermatologist/crisp-t/tree/v0.8.0) (2025-10-22)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.7.0...v0.8.0)

**Implemented enhancements:**

- Feature request: LDA output Visualization for text mining [\#38](https://github.com/dermatologist/crisp-t/issues/38)

## [v0.7.0](https://github.com/dermatologist/crisp-t/tree/v0.7.0) (2025-10-21)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.6.0...v0.7.0)

**Implemented enhancements:**

- Feature request: Add a progress bar for long running functions. [\#36](https://github.com/dermatologist/crisp-t/issues/36)

## [v0.6.0](https://github.com/dermatologist/crisp-t/tree/v0.6.0) (2025-10-19)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.5.0...v0.6.0)

**Implemented enhancements:**

- Feature request: Add LSTM method to ml.py. [\#34](https://github.com/dermatologist/crisp-t/issues/34)

## [v0.5.0](https://github.com/dermatologist/crisp-t/tree/v0.5.0) (2025-10-18)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.4.0...v0.5.0)

**Closed issues:**

- Feature request: Semantic Search based on a list of documents [\#32](https://github.com/dermatologist/crisp-t/issues/32)

## [v0.4.0](https://github.com/dermatologist/crisp-t/tree/v0.4.0) (2025-10-15)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.3.0...v0.4.0)

**Closed issues:**

- Feature request: Semantic Search for a concept within a document [\#30](https://github.com/dermatologist/crisp-t/issues/30)

## [v0.3.0](https://github.com/dermatologist/crisp-t/tree/v0.3.0) (2025-10-12)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.2.0...v0.3.0)

**Implemented enhancements:**

- Feature request: Semantic Search with chromadb and metadata export as dataframe [\#27](https://github.com/dermatologist/crisp-t/issues/27)

## [v0.2.0](https://github.com/dermatologist/crisp-t/tree/v0.2.0) (2025-10-10)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/v0.1.0...v0.2.0)

## [v0.1.0](https://github.com/dermatologist/crisp-t/tree/v0.1.0) (2025-10-10)

[Full Changelog](https://github.com/dermatologist/crisp-t/compare/b44ec69181fd0c0204a1692c494a2a36e7c4177e...v0.1.0)

**Implemented enhancements:**

- Feature Request: Create an MCP server [\#20](https://github.com/dermatologist/crisp-t/issues/20)
- Feature request: Add Linear and Logistic regression [\#18](https://github.com/dermatologist/crisp-t/issues/18)
- Feature: Command line interface and Documentation. [\#12](https://github.com/dermatologist/crisp-t/issues/12)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
